#This document explores spatial patterns with distance in paleomagnetic data from Tjornes and Flateyjarskagi. 
#Tjornes paleomagnetic data do not appear to form a gradient with fault normal distance. The data from Flateyjarskagi do change with fault-normal distance to a statistically significant degree. 
#However, the data from Tjornes span from approximately 0 to 7 km from the Husavik-Flatey fault and the data from flateyjarksgi cover a larger range of distances, so it is possible that 
#the pattern is not recorded in the Tjornes data due to more limited spatial coverage.
#Therefore, we examine data from Flateyjarskagi within the 0-7km distance range to determine if a pattern is detectable. 


setwd("~/Desktop/geologyGeometry")
source("~/Desktop/geologyGeometry/library/all.R")
source("~/Desktop/geologyGeometry/loadStructures2018.R")

TitusPmag <- pMag[1,]
TitusPmag$vector <- "NA"
for (i in (1:nrow(pMag))){
  row <- pMag[i,]
  trend <- row$trendDeg
  plunge <- row$plungeDeg
  row$vector <- list(geoCartesianFromTrendPlungeDeg(c(trend, plunge)))
  TitusPmag <- rbind(TitusPmag, row)
}
TitusPmag <- TitusPmag[-1,]

HorstPmag <- horstPmag[1,]
HorstPmag$vector <- "NA"
for (i in (1:nrow(horstPmag))){
  row <- horstPmag[i,]
  trend <- row$trendDeg
  plunge <- row$plungeDeg
  row$vector <- list(geoCartesianFromTrendPlungeDeg(c(trend, plunge)))
  HorstPmag <- rbind(HorstPmag, row)
}
HorstPmag <- HorstPmag[-1,]


TitusPmag <- dplyr::select(TitusPmag, "vector", "easting", "northing", "distance", "strikedist", "lithology", "strikeDeg", "dipDeg")
HorstPmag <- dplyr::select(HorstPmag, "vector", "easting", "northing", "distance", "strikedist", "lithology", "strikeDeg", "dipDeg")
TitusPmag <- rbind(TitusPmag, HorstPmag)


#remove outliers
TitusPmag$strike <- lapply(TitusPmag$vector, function(vec) geoStrikeDipDegFromCartesian(vec)[1])
TitusPmag$dip <- lapply(TitusPmag$vector, function(vec) geoStrikeDipDegFromCartesian(vec)[2])
PmagOriginal <- TitusPmag
interm <- filter(TitusPmag, dip < 30, strike < 90)
TitusPmag <- filter(TitusPmag, strike > 90)
TitusPmag <- filter(TitusPmag, strike < 290)
TitusPmag <- rbind(TitusPmag, interm)
lineEqualAreaPlot(PmagOriginal$vector)
lineEqualAreaPlot(TitusPmag$vector) #outliers removed



TitusPmag1 <- filter(TitusPmag, distance < 7000) #max distance for TJ data is 6730
TitusPmag1$hues <- hue(TitusPmag1$distance)

#TJ GRADIENT VS FL GRADIENT
FLpmag <- filter(TitusPmag, easting < 660000) #for some reason FL pattern is stronger in the dikes-consider treating dikes and lavas separately
nFLpmag <- filter(TitusPmag1, easting < 660000)
TJpmag <- filter(TitusPmag1, easting > 660000)
TJpmag <- filter(TJpmag, strike >170) #remove outlier.  
nFLlava <- filter(nFLpmag, lithology=="L")

#Maps of locations on Flateyjarskagi and Tjornes
plot(nFLpmag$easting, nFLpmag$northing, col=nFLpmag$hues)
plot(nFLlava$easting, nFLlava$northing, col=nFLlava$hues)
plot(TJpmag$easting, TJpmag$northing, col=TJpmag$hues)

lineEqualAreaPlot(nFLpmag$vector, colors=nFLpmag$hues)#all Flateyjarskagi remanence directons
lineEqualAreaPlot(nFLlava$vector, colors=nFLlava$hues)#Flateyjarskagi pmag data from lavas only
lineEqualAreaPlot(TJpmag$vector, colors=TJpmag$hues)#all Tjornes pmag 


#compute regressions of paleomag directions on fault-normal distance
originalFLreg <- lineRescaledSmallCircleRegression(FLpmag$distance, FLpmag$vector, numSteps=1000, numPoints=0)
FLpmagReg <- lineRescaledSmallCircleRegression(nFLpmag$distance, nFLpmag$vector, numSteps=1000, numPoints=0)
TJpmagReg <- lineRescaledSmallCircleRegression(TJpmag$distance, TJpmag$vector, numSteps=1000, numPoints=0)
FLpmagLReg <- lineRescaledSmallCircleRegression(nFLlava$distance, nFLlava$vector, numSteps=1000, numPoints=0)

originalFLreg #r squared is 0.218 for all FL pmag data
FLpmagReg #r squared is 0.095 for FL pmag data nearer than 7 km from the fault
FLpmagLReg #r squared is 0.047
TJpmagReg #r squared is 0.12

#visualize the regression:
xs <- 1:7
xs <- sapply(xs, function(x) x*1000)
ls <- lapply(xs, FLpmagLReg$prediction) #plug in a regression here 
lineEqualAreaPlot(ls, colors=hues(xs))#good enough
min(nFLlava$distance) #note that min FL lava reg distance is 1991 m so very near fault prediction doesn't apply well. 


#determine regresion significance (p-value)
numPerms <- 1000
df <- nFLpmag #plug in a pmag data set here
g <- function(i){
  print(i / numPerms)
  newXs <- sample(df$distance, size=length(df$distance)) 
  lineRescaledSmallCircleRegression(newXs, df$vector, numSteps=100, numPoints=0)}

perms <- sapply(1:numPerms, g)
perms[5,]
length(perms[5,])
#how many failed?
j = 0
for (i in 1:length(perms[1,])){
  if (perms[1,i] > 0){
    j = j+1 
    print(i)
    perms[5,i] <- 0#make sure none of the failed regressions have r squared values higher than the original regression
    }} #5 failed for TJperms, 23 failed for FLperms, 116 failed out of 1000 FL 

#find p-value
j = 0
for (i in perms[5,]){
  if (i > pmagReg$rSquared){
    j = j+1 
    print(i)}#prints the rsquared values for the regressions with higher rsquared values than the original
}
#with outliers removed, 1 permuted regression out of (1000-116 failed) is more significant than the original Flateyjarskagi regression

#37 of 1000 TJ perms failed
#TJ: 98 out of (1000-37 have higher p values) are more significant than the original

#neither regression is significant with only lava data
#The Flateyjarskagi regression is not particularly significant when outliers are included (p=0.079)













